summaryrefslogtreecommitdiff
path: root/src/sysdep.c
diff options
context:
space:
mode:
authorKarl Heuer <kwzh@gnu.org>1996-01-04 22:59:13 +0000
committerKarl Heuer <kwzh@gnu.org>1996-01-04 22:59:13 +0000
commitc58921ade397a05301f28caeff47dc6cdc463499 (patch)
tree04efe035530cccc9d6c7bc92770c9ec84326144d /src/sysdep.c
parentee360acac22bdfa7986bf0632ad07252221f92aa (diff)
downloademacs-c58921ade397a05301f28caeff47dc6cdc463499.tar.gz
(WRITABLE): Renamed from WRITEABLE.
Diffstat (limited to 'src/sysdep.c')
-rw-r--r--src/sysdep.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/sysdep.c b/src/sysdep.c
index 96fc515b76c..dab274774d6 100644
--- a/src/sysdep.c
+++ b/src/sysdep.c
@@ -1314,7 +1314,7 @@ init_sys_modes ()
#endif /* VSTOP */
#endif /* mips or HAVE_TCATTR */
#ifdef SET_LINE_DISCIPLINE
- /* Need to explicitely request TERMIODISC line discipline or
+ /* Need to explicitly request TERMIODISC line discipline or
Ultrix's termios does not work correctly. */
tty.main.c_line = SET_LINE_DISCIPLINE;
#endif
@@ -2029,7 +2029,7 @@ start_of_text ()
* at least on UniPlus, is temacs will have to be made unshared so
* that text and data are contiguous. Then once loadup is complete,
* unexec will produce a shared executable where the data can be
- * at the normal shared text boundry and the startofdata variable
+ * at the normal shared text boundary and the startofdata variable
* will be patched by unexec to the correct value.
*
*/
@@ -2795,7 +2795,7 @@ sys_abort ()
#ifdef VMS
#ifdef LINK_CRTL_SHARE
-#ifdef SHAREABLE_LIB_BUG
+#ifdef SHARABLE_LIB_BUG
/* Variables declared noshare and initialized in sharable libraries
cannot be shared. The VMS linker incorrectly forces you to use a private
version which is uninitialized... If not for this "feature", we
@@ -2841,7 +2841,7 @@ char *sys_errlist[] =
"I/O stream empty",
"vax/vms specific error code nontranslatable error"
};
-#endif /* SHAREABLE_LIB_BUG */
+#endif /* SHARABLE_LIB_BUG */
#endif /* LINK_CRTL_SHARE */
#endif /* VMS */
@@ -3040,7 +3040,7 @@ char *sys_siglist[NSIG + 1] =
#ifdef sun
"window size change", /* 20 SIGWINCH */
"urgent socket condition", /* 21 SIGURG */
- "pollable event occured", /* 22 SIGPOLL */
+ "pollable event occurred", /* 22 SIGPOLL */
"stop (cannot be caught or ignored)", /* 23 SIGSTOP */
"user stop requested from tty", /* 24 SIGTSTP */
"stopped process has been continued", /* 25 SIGCONT */
@@ -3760,7 +3760,7 @@ sys_access (filename, type)
/* Check write protection. */
#define CHECKPRIV(bit) (prvmask.bit)
-#define WRITEABLE(field) (! ((xab.xab$w_pro >> field) & XAB$M_NOWRITE))
+#define WRITABLE(field) (! ((xab.xab$w_pro >> field) & XAB$M_NOWRITE))
/* Find privilege bits */
status = SYS$SETPRV (0, 0, 0, prvmask);
@@ -3781,7 +3781,7 @@ sys_access (filename, type)
return -1;
SYS$CLOSE (&fab, 0, 0);
/* Check system access */
- if (CHECKPRIV (PRV$V_SYSPRV) && WRITEABLE (XAB$V_SYS))
+ if (CHECKPRIV (PRV$V_SYSPRV) && WRITABLE (XAB$V_SYS))
return 0;
/* Check ACL entries, if any */
acl_controlled = 0;
@@ -3807,16 +3807,16 @@ sys_access (filename, type)
return -1;
}
/* No ACL entries specified, check normal protection */
- if (WRITEABLE (XAB$V_WLD)) /* World writeable */
+ if (WRITABLE (XAB$V_WLD)) /* World writable */
return 0;
- if (WRITEABLE (XAB$V_GRP) &&
+ if (WRITABLE (XAB$V_GRP) &&
(unsigned short) (xab.xab$l_uic >> 16) == grpid)
- return 0; /* Group writeable */
- if (WRITEABLE (XAB$V_OWN) &&
+ return 0; /* Group writable */
+ if (WRITABLE (XAB$V_OWN) &&
(xab.xab$l_uic & 0xFFFF) == memid)
- return 0; /* Owner writeable */
+ return 0; /* Owner writable */
- return -1; /* Not writeable */
+ return -1; /* Not writable */
}
#endif /* not VMS4_4 */
#endif /* access */
@@ -4499,7 +4499,7 @@ cnv_uaf_pw (up)
retpw.pw_uid = up->uaf$w_mem;
retpw.pw_gid = up->uaf$w_grp;
- /* I suppose this is not the best sytle, to possibly overwrite one
+ /* I suppose this is not the best style, to possibly overwrite one
byte beyond the end of the field, but what the heck... */
ptr = &up->uaf$t_username[UAF$S_USERNAME];
while (ptr[-1] == ' ')